##  Step 1: Get the Report Code
Follow these steps:
  1. In SAP LeanIX, open the report that you want to embed.
  2. In the upper-right corner of the report page, click the ellipses icon, then select Export > HTML Embed Code.
![Navigating to the HTML Embed Code Option on the Report Page](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275112ad7a441014b97f8b3cb2cefbf4_LowRes.png)
Navigating to the HTML Embed Code Option on the Report Page
  3. Copy the iframe code of the report.
![Iframe Code for an Example Report](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274fff587a441014bb159205834cd52f_LowRes.png)
Iframe Code for an Example Report
